/* ====================================================================
 * The Apache Software License, Version 1.1
 *
 * Copyright (c) 2001 David Dribin.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 *
 * 3. The end-user documentation included with the redistribution,
 *    if any, must include the following acknowledgment:
 *       "This product includes software developed by the
 *        Apache Software Foundation (http://www.apache.org/)."
 *    Alternately, this acknowledgment may appear in the software itself,
 *    if and wherever such third-party acknowledgments normally appear.
 *
 * 4. The names "Ant" and "Apache Software Foundation" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact apache@apache.org.
 *
 * 5. Products derived from this software may not be called "Apache",
 *    nor may "Apache" appear in their name, without prior written
 *    permission of the Apache Software Foundation.
 *
 * THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED.  IN NO EVENT SHALL THE APACHE SOFTWARE FOUNDATION OR
 * ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
 * USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
 * OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 * ====================================================================
 *
 * This software consists of voluntary contributions made by many
 * individuals on behalf of the Apache Software Foundation.  For more
 * information on the Apache Software Foundation, please see
 * <http://www.apache.org/>.
 */

package org.dribin.dave.ant.j2me.util;

import java.io.File;

import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.Path;

public class KvmHelper
{
    public KvmHelper(Project project)
    {
        StringBuffer    cldcPath;
        StringBuffer    kjavaPath;
        StringBuffer    palmToolsPath;
        File            pathElement;
        
        mProject    = project;
        mJ2meHome   = mProject.getProperty("j2me.home");
        mCldcHome   = mProject.getProperty("j2me.cldc.home");
        mKjavaHome  = mProject.getProperty("j2me.kjava.home");
        mPalmToolsHome   = mProject.getProperty("j2me.palmtools.home");

        if (mCldcHome == null)
        {
            mCldcHome   = mJ2meHome;
        }

        if (mKjavaHome == null)
        {
            mKjavaHome  = mCldcHome;
        }
        
        if (mPalmToolsHome == null)
        {
            mPalmToolsHome  = mKjavaHome;
        }

        if (mCldcHome != null)
        {
            mCldcClassPath  = new Path(project);
            mKjavaClassPath = new Path(project);
            mPalmToolsClassPath = new Path(project);

            cldcPath    = new StringBuffer(mCldcHome);
            cldcPath.append(File.separator);
            cldcPath.append("bin").append(File.separator);
            cldcPath.append("common").append(File.separator);
            cldcPath.append("api").append(File.separator);
            cldcPath.append("classes");
            pathElement     = new File(cldcPath.toString());
            mCldcClassPath.setLocation(pathElement);
            mKjavaClassPath.setLocation(pathElement);
            mPalmToolsClassPath.setLocation(pathElement);

            kjavaPath   = new StringBuffer(mKjavaHome);
            kjavaPath.append(File.separator);
            kjavaPath.append("bin").append(File.separator);
            kjavaPath.append("kjava").append(File.separator);
            kjavaPath.append("api").append(File.separator);
            kjavaPath.append("classes");
            pathElement     = new File(kjavaPath.toString());
            mKjavaClassPath.setLocation(pathElement);
            mPalmToolsClassPath.setLocation(pathElement);

            palmToolsPath   = new StringBuffer(mPalmToolsHome);
            palmToolsPath.append(File.separator);
            palmToolsPath.append("bin").append(File.separator);
            palmToolsPath.append("kjava").append(File.separator);
            palmToolsPath.append("tools").append(File.separator);
            palmToolsPath.append("palm").append(File.separator);
            palmToolsPath.append("classes");
            pathElement     = new File(palmToolsPath.toString());
            mPalmToolsClassPath.setLocation(pathElement);
        }
    }

    public String getJ2meHome()
    {
        return mJ2meHome;
    }
    
    public String getCldcHome()
    {
        return mJ2meHome;
    }

    public String getKjavaHome()
    {
        return mKjavaHome;
    }
    
    public String getPlamToolsHome()
    {
        return mPalmToolsHome;
    }

    public Path getCldcClassPath()
    {
        return mCldcClassPath;
    }

    public Path getKjavaClassPath()
    {
        return mKjavaClassPath;
    }
    
    public Path getPalmToolsClassPath()
    {
        return mPalmToolsClassPath;
    }

    private Project                 mProject;
    private String                  mJ2meHome;
    private String                  mCldcHome;
    private String                  mKjavaHome;
    private String                  mPalmToolsHome;
    private Path                    mCldcClassPath;
    private Path                    mKjavaClassPath;
    private Path                    mPalmToolsClassPath;
}
